@@ -3,8 +3,9 @@ Submodule for more specific types which are relevant to
 surface-extraction subroutines of the CIVET pipeline.
 """
 
-from civet.extraction.hemisphere import HemisphereMask, Side
-from civet.extraction.surfaces import RegularSurface, IrregularSurface
+from civet.extraction.side import Side
+from civet.extraction.hemisphere import HemisphereMask
+from civet.extraction.surfaces import RegularSurface, IrregularSurface, Tetra
 from civet.extraction.starting_models import SurfaceModel
 
 __all__ = [
@@ -12,5 +13,6 @@ __all__ = [
     'Side',
     'RegularSurface',
     'IrregularSurface',
+    'Tetra',
     'SurfaceModel'
 ]
